%define	major		1
%define libname		%mklibname user %{major}
%define develname	%mklibname user -d

# we don't want to provide private python extension libs
%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

%bcond_with selinux

Summary:	A user and group account administration library
Name:		libuser
Version:	0.64
Release:	%mkrel 3
License:	LGPLv2+
Group:		System/Configuration
# VCS: https://fedorahosted.org/libuser/browser
URL:		https://pagure.io/libuser
Source0:	http://releases.pagure.org/libuser/%{name}-%{version}.tar.gz
# crypt returns *0 if key is small than 22 and rounds are not given
Patch2:		libuser-0.64-fix_blowfish.patch
Patch3:		libuser-0.62-create-homedir-segfault.patch
BuildRequires:	gettext-devel
BuildRequires:	glib2-devel
BuildRequires:	openldap-devel
BuildRequires:	linuxdoc-tools
BuildRequires:	pam-devel
BuildRequires:	popt-devel
%if %{with selinux}
BuildRequires:	selinux-devel
%endif
BuildRequires:	bison
BuildRequires:	openssl
BuildRequires:	locales-en
BuildRequires:	python3-devel
BuildRequires:	bison
BuildRequires:	gtk-doc

Requires:	coreutils
Requires(pre):	coreutils

%description
The libuser library implements a standardized interface for manipulating
and administering user and group accounts.  The library uses pluggable
back-ends to interface to its data sources.

Sample applications modeled after those included with the shadow password
suite are included.

%package -n python3-%{name}
Group:		Development/Python
Summary:	Library bindings for python3
Requires:	%{libname} = %{version}-%{release}

Obsoletes:	libuser-python3 < 0.62-15
Provides:	libuser-python3 = %{version}-%{release}

%description -n python3-%{name}
This package contains the python3 library for python3 applications that
use libuser.

%package ldap
Group:		System/Libraries
Summary:	Libuser ldap library
Requires:	%{libname} = %{version}-%{release}

%description ldap
This package contains the libuser ldap library.

%package -n %{libname}
Group:		System/Libraries
Summary:	The actual libraries for libuser
Requires:	%{name} = %{version}-%{release}

%description -n	%{libname}
This is the actual library for the libuser library.

%package -n %{develname}
Group:		Development/C
Summary:	Files needed for developing applications which use libuser
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
The libuser-devel package contains header files, static libraries, and other
files useful for developing applications with libuser.

%prep
%autosetup -p1

%build
./autogen.sh
%configure \
	--with-ldap \
	--with-python \
	--with-popt \
	--without-sasl \
	--disable-rpath \
%if %{with selinux}
	--with-selinux \
%endif
	--enable-gtk-doc \
	--with-html-dir=%{_datadir}/gtk-doc/html \
	PYTHON=%{__python3}
%make_build

%install
%make_install

%find_lang %{name}

# Remove unpackaged files
rm -rf  %{buildroot}%{python3_sitearch}/*a \
        %{buildroot}%{_libdir}/%{name}/*.la \
        %{buildroot}%{_libdir}/*.la

%if 0
%check
make check

LD_LIBRARY_PATH=%{buildroot}%{_libdir}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH

# Verify that all python modules load, just in case.
pushd %{buildroot}%{python3_sitearch}/
# The Python 3 module only supports UTF-8
LC_ALL=en_US.UTF-8 \
%{__python3} -c "import libuser"
popd
%endif

# (mga6) fix update to 0.62 or to CVE-2015-3246:
%triggerin -n %{libname} -- %{libname} <= 0.62-8.mga6
rm -f /etc/shadow.lock

%files -f %{name}.lang
%doc AUTHORS NEWS README TODO docs/*.txt python/modules.txt
%config(noreplace) %{_sysconfdir}/libuser.conf
%{_bindir}/*
%{_sbindir}/*
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/libuser_files.so
%{_libdir}/%{name}/libuser_shadow.so
%{_mandir}/man5/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libuser.so.%{major}{,.*}

%files -n python3-%{name}
%{python3_sitearch}/*.so

%files ldap
%{_libdir}/%{name}/libuser_ldap.so

%files -n %{develname}
%{_includedir}/libuser/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/*


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 0.64-3.mga10
+ Revision: 2242840
- Mageia 10 Mass Rebuild

* Tue Mar 04 2025 wally <wally> 0.64-2.mga10
+ Revision: 2160359
- rebuild for python3.13

* Fri Apr 05 2024 wally <wally> 0.64-1.mga10
+ Revision: 2054954
- new version 0.64
- basesystem rebuild for i686

* Sun Feb 11 2024 daviddavid <daviddavid> 0.63-6.mga10
+ Revision: 2040193
- rebuild for py3.12

* Tue Jan 03 2023 umeabot <umeabot> 0.63-5.mga9
+ Revision: 1929544
- Rebuild to use libldap-2.5 instead of 2.4

* Thu Jun 09 2022 tv <tv> 0.63-4.mga9
+ Revision: 1863711
- Build w/o selinux in order to unbloat minimal install

* Wed Mar 30 2022 umeabot <umeabot> 0.63-3.mga9
+ Revision: 1833790
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tmb <tmb> 0.63-2.mga9
+ Revision: 1774947
- rebuild for python 3.10

* Sun Mar 28 2021 daviddavid <daviddavid> 0.63-1.mga9
+ Revision: 1711458
- new version: 0.63

* Sat Mar 27 2021 daviddavid <daviddavid> 0.62-17.mga9
+ Revision: 1710992
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 0.62-16.mga8
+ Revision: 1533455
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 22 2019 daviddavid <daviddavid> 0.62-15.mga8
+ Revision: 1444546
- rebuild for python3.8
- drop python2 support
- rename libuser-python3 to python3-libuser

* Tue Jan 08 2019 daviddavid <daviddavid> 0.62-14.mga7
+ Revision: 1352789
- rebuild for new Python 3.7

* Sun Sep 23 2018 umeabot <umeabot> 0.62-13.mga7
+ Revision: 1299203
- Mageia 7 Mass Rebuild

* Tue Jan 09 2018 mrambo3501 <mrambo3501> 0.62-12.mga7
+ Revision: 1191908
- update segfault patch for suggestions in mga#21333:C7
- update segfault patch for suggestions in mga#21333:C7

* Sun Dec 31 2017 mrambo3501 <mrambo3501> 0.62-10.mga7
+ Revision: 1188433
- add patch to fix a segfault when creating a user for home directory that already exists mga#21333

* Sat Aug 05 2017 pterjan <pterjan> 0.62-9.mga7
+ Revision: 1135262
- Rebuild for python 3.6

* Thu Aug 04 2016 philippem <philippem> 0.62-8.mga6
+ Revision: 1044454
- rebuild for new pam
- rebuild for new pam

* Thu Aug 04 2016 philippem <philippem> 0.62-6.mga6
+ Revision: 1044437
- rebuild for pam

* Mon Jul 11 2016 philippem <philippem> 0.62-5.mga6
+ Revision: 1041167
- don't use blowfish (#17504)

* Wed May 04 2016 philippem <philippem> 0.62-4.mga6
+ Revision: 1009231
- try to fix mga#18301, add requires coreutils

* Thu Apr 07 2016 philippem <philippem> 0.62-3.mga6
+ Revision: 999081
- add a trigger to fix mga#17095, stay with default blowfish

* Tue Dec 29 2015 luigiwalser <luigiwalser> 0.62-2.mga6
+ Revision: 916774
- python3 build fixes from daviddavid
- try to bypass linker error for now to build with python3 support
- try enabling python3 build

* Fri Dec 25 2015 luigiwalser <luigiwalser> 0.62-1.mga6
+ Revision: 914504
- 0.62
- remove upstreamed CVE-2015-3246 patch

* Fri Aug 21 2015 tmb <tmb> 0.60-8.mga6
+ Revision: 867768
- rebuild for new gcc
+ philippem <philippem>
- Python3 will be supported in 0.62 Fedora have it, prepare the spec for it
+ tv <tv>
- tag the trigger as mga6 so that it can be dropped in eg: mga[89]

* Tue Aug 04 2015 tv <tv> 0.60-7.mga6
+ Revision: 860976
- drop patch 1 (we're now defaulting to SHA-512 passwords instead of blowfish) (mga#16467)
- fix update to 0.62 or to CVE-2015-3246 (mga#16467)
- kill commented out sasl subpackage
  (fix "warning: Macro expanded in comment")
- add VCS URL

* Thu Jul 23 2015 luigiwalser <luigiwalser> 0.60-6.mga6
+ Revision: 856568
- add patch from redhat to fix CVE-2015-3245 and CVE-2015-3246

* Wed Oct 15 2014 umeabot <umeabot> 0.60-5.mga5
+ Revision: 741989
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.60-4.mga5
+ Revision: 726906
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 0.60-2.mga4
+ Revision: 545171
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 luigiwalser <luigiwalser> 0.60-1.mga4
+ Revision: 500867
- 0.60

* Mon Apr 01 2013 luigiwalser <luigiwalser> 0.59-1.mga3
+ Revision: 406909
- 0.59 (fixes CVE-2012-5630 and CVE-2012-5644)

* Wed Jan 23 2013 fwang <fwang> 0.58-3.mga3
+ Revision: 391472
- update rpm group

* Sat Jan 12 2013 umeabot <umeabot> 0.58-2.mga3
+ Revision: 358310
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 25 2012 luigiwalser <luigiwalser> 0.58-1.mga3
+ Revision: 334810
- 0.58

* Sun Oct 07 2012 luigiwalser <luigiwalser> 0.57.7-1.mga3
+ Revision: 303114
- 0.57.7

* Sun Jul 29 2012 luigiwalser <luigiwalser> 0.57.6-1.mga3
+ Revision: 275657
- 0.57.6

* Sat Dec 10 2011 tv <tv> 0.57.3-1.mga2
+ Revision: 180324
- new release

* Thu Sep 08 2011 tv <tv> 0.57.2-1.mga2
+ Revision: 141502
- new release

* Tue Sep 06 2011 tv <tv> 0.57.1-1.mga2
+ Revision: 139509
- new release
- rediff patch 1

* Wed Jan 12 2011 blino <blino> 0.56.18-4.mga1
+ Revision: 6664
- remove old conflicts and ldconfig scriptlets
- imported package libuser


* Thu Nov 04 2010 Götz Waschk <waschk@mandriva.org> 0.56.18-3mdv2011.0
+ Revision: 593320
- rebuild for new python 2.7

* Thu Sep 16 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.56.18-1mdv2011.0
+ Revision: 579049
- update to new version 0.56.18

* Sun Aug 29 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.56.17-1mdv2011.0
+ Revision: 574111
- update to new version 0.56.17

* Sat Aug 07 2010 Funda Wang <fwang@mandriva.org> 0.56.16-2mdv2011.0
+ Revision: 567458
- rebuild

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update to new version 0.56.16

* Thu May 20 2010 Pascal Terjan <pterjan@mandriva.org> 0.56.15-3mdv2010.1
+ Revision: 545479
- fix blowfish encoding

* Tue May 18 2010 Pascal Terjan <pterjan@mandriva.org> 0.56.15-2mdv2010.1
+ Revision: 545158
- default to blowfish for passwords instead of md5 (#59158)

* Sat Mar 20 2010 Emmanuel Andry <eandry@mandriva.org> 0.56.15-1mdv2010.1
+ Revision: 525491
- New version 0.56.15

* Sat Feb 13 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.56.14-1mdv2010.1
+ Revision: 505549
- update to new version 0.56.14
- drop patches 1 and 2, fixed upstream

  + Thierry Vignaud <tv@mandriva.org>
    - add patches status

* Tue Feb 02 2010 Thierry Vignaud <tv@mandriva.org> 0.56.13-2mdv2010.1
+ Revision: 499466
- fix build on x86_64
- patch 1: fix translating in library callers (eg: userdrake)
- patch 2: update french translation

* Thu Dec 31 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.56.13-1mdv2010.1
+ Revision: 484480
- update to new version 0.56.13

* Sat Nov 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.56.12-1mdv2010.1
+ Revision: 462242
- update to new version 0.56.12

* Wed Sep 23 2009 Emmanuel Andry <eandry@mandriva.org> 0.56.11-1mdv2010.0
+ Revision: 447892
- New version 0.56.11

* Sun Jun 28 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.56.10-1mdv2010.0
+ Revision: 390224
- disable sasl support
- update to new version 0.56.10
- enable sasl support
- disable rpath
- do not package COPYING file
- spec file clean

* Sat Dec 27 2008 Funda Wang <fwang@mandriva.org> 0.56.9-3mdv2009.1
+ Revision: 319796
- fix str fmt
- rebuild for new python

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0.56.9-2mdv2009.0
+ Revision: 264935
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sun Jun 01 2008 Funda Wang <fwang@mandriva.org> 0.56.9-1mdv2009.0
+ Revision: 213923
- New version 0.56.9

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Wed Dec 26 2007 Oden Eriksson <oeriksson@mandriva.com> 0.56.4-2mdv2008.1
+ Revision: 137968
- rebuilt against openldap-2.4.7 libs

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Aug 17 2007 Thierry Vignaud <tv@mandriva.org> 0.56.4-1mdv2008.0
+ Revision: 64895
- new release


* Tue Jan 30 2007 Götz Waschk <waschk@mandriva.org> 0.54.5-2mdv2007.0
+ Revision: 115557
- fix devel package conflicting with the main one

* Tue Jan 30 2007 Götz Waschk <waschk@mandriva.org> 0.54.5-1mdv2007.1
+ Revision: 115454
- Import libuser

* Tue Jan 30 2007 Götz Waschk <waschk@mandriva.org> 0.54.5-1mdv2007.1
- rebuild

* Thu Apr 13 2006 Thierry Vignaud <tvignaud@mandriva.com> 0.54.5-1mdk
- new release (fix #21962)
- use %%mkrel

* Wed Sep 07 2005 Oden Eriksson <oeriksson@mandriva.com> 0.53.2-6mdk
- pass "-DLDAP_DEPRECATED" to the CFLAGS

* Wed Aug 31 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.53.2-5mdk
- Rebuild for new libldap-2.3
- buildrequire openldap-devel, not libldap-devel

* Thu Aug 25 2005 Daouda LO <daouda@mandrakesoft.com> 0.53.2-4mdk
- split out libldap into a new package

* Mon Feb 14 2005 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.53.2-3mdk
- mklibname

* Fri Feb 04 2005 Buchan Milne <bgmilne@linux-mandrake.com> 0.53.2-2mdk
- rebuild for ldap2.2_7

* Thu Jan 20 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.53.2-1mdk
- 0.53.2

* Mon Jan 03 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.53.1-1mdk
- 0.53.1
- cosmetics

* Tue Dec 07 2004 Gåtz Waschk <waschk@linux-mandrake.com> 0.53-1mdk
- add new files
- drop all patches
- remove useless files from the devel package
- use pyver macro
- new version

* Tue May 18 2004 Nicolas Planel <nplanel@mandrakesoft.com> 0.51.7-10mdk
- security fix (MDKSA-2004:044).

* Wed Mar 24 2004 Daouda LO <daouda@mandrakesoft.com> 0.51.7-9mdk
- Obsoletes libuser < 0.51-6mdk (9.1 version)

